IssuedDocument

Struct IssuedDocument 

pub struct IssuedDocument {
Show 85 fields pub id: Option<Option<i32>>, pub entity: Option<Box<Entity>>, pub type: Option<Type>, pub number: Option<Option<i32>>, pub numeration: Option<Option<String>>, pub date: Option<Option<String>>, pub year: Option<Option<i32>>, pub currency: Option<Box<Currency>>, pub language: Option<Box<Language>>, pub subject: Option<Option<String>>, pub visible_subject: Option<Option<String>>, pub rc_center: Option<Option<String>>, pub notes: Option<Option<String>>, pub rivalsa: Option<Option<f64>>, pub cassa: Option<Option<f64>>, pub amount_cassa: Option<Option<f64>>, pub cassa_taxable: Option<Option<f64>>, pub amount_cassa_taxable: Option<Option<f64>>, pub cassa2: Option<Option<f64>>, pub amount_cassa2: Option<Option<f64>>, pub cassa2_taxable: Option<Option<f64>>, pub amount_cassa2_taxable: Option<Option<f64>>, pub global_cassa_taxable: Option<Option<f64>>, pub amount_global_cassa_taxable: Option<Option<f64>>, pub withholding_tax: Option<Option<f64>>, pub withholding_tax_taxable: Option<Option<f64>>, pub other_withholding_tax: Option<Option<f64>>, pub stamp_duty: Option<Option<f64>>, pub payment_method: Option<Box<PaymentMethod>>, pub use_split_payment: Option<Option<bool>>, pub use_gross_prices: Option<Option<bool>>, pub e_invoice: Option<Option<bool>>, pub ei_data: Option<Option<Box<IssuedDocumentEiData>>>, pub ei_cassa_type: Option<Option<String>>, pub ei_cassa2_type: Option<Option<String>>, pub ei_withholding_tax_causal: Option<Option<String>>, pub ei_other_withholding_tax_type: Option<Option<String>>, pub ei_other_withholding_tax_causal: Option<Option<String>>, pub items_list: Option<Option<Vec<IssuedDocumentItemsListItem>>>, pub payments_list: Option<Option<Vec<IssuedDocumentPaymentsListItem>>>, pub template: Option<Box<DocumentTemplate>>, pub delivery_note_template: Option<Box<DocumentTemplate>>, pub acc_inv_template: Option<Box<DocumentTemplate>>, pub h_margins: Option<Option<i32>>, pub v_margins: Option<Option<i32>>, pub show_payments: Option<Option<bool>>, pub show_payment_method: Option<Option<bool>>, pub show_totals: Option<ShowTotals>, pub show_notification_button: Option<Option<bool>>, pub show_tspay_button: Option<Option<bool>>, pub delivery_note: Option<Option<bool>>, pub accompanying_invoice: Option<Option<bool>>, pub dn_number: Option<Option<i32>>, pub dn_date: Option<Option<String>>, pub dn_ai_packages_number: Option<Option<String>>, pub dn_ai_weight: Option<Option<String>>, pub dn_ai_causal: Option<Option<String>>, pub dn_ai_destination: Option<Option<String>>, pub dn_ai_transporter: Option<Option<String>>, pub dn_ai_notes: Option<Option<String>>, pub is_marked: Option<Option<bool>>, pub amount_net: Option<Option<f64>>, pub amount_vat: Option<Option<f64>>, pub amount_gross: Option<Option<f64>>, pub amount_due_discount: Option<Option<f64>>, pub amount_rivalsa: Option<Option<f64>>, pub amount_rivalsa_taxable: Option<Option<f64>>, pub amount_withholding_tax: Option<Option<f64>>, pub amount_withholding_tax_taxable: Option<Option<f64>>, pub amount_other_withholding_tax: Option<Option<f64>>, pub amount_other_withholding_tax_taxable: Option<Option<f64>>, pub amount_enasarco_taxable: Option<Option<f64>>, pub extra_data: Option<Option<Box<IssuedDocumentExtraData>>>, pub seen_date: Option<Option<String>>, pub next_due_date: Option<Option<String>>, pub url: Option<Option<String>>, pub dn_url: Option<Option<String>>, pub ai_url: Option<Option<String>>, pub attachment_url: Option<Option<String>>, pub attachment_token: Option<Option<String>>, pub ei_raw: Option<Option<Value>>, pub ei_status: Option<Option<EiStatus>>, pub locked: Option<Option<bool>>, pub created_at: Option<Option<String>>, pub updated_at: Option<Option<String>>,
}

Fields

id: Option<Option<i32>>

Issued document id

entity: Option<Box<Entity>>type: Option<Type>

Issued document type

number: Option<Option<i32>>

Issued document number [If not specified, next number is used]

numeration: Option<Option<String>>

Issued document numeration [Not available if type=delivery_note]

date: Option<Option<String>>

Issued document date [defaults to today’s date]

year: Option<Option<i32>>

Issued document year

currency: Option<Box<Currency>>language: Option<Box<Language>>subject: Option<Option<String>>

Issued document subject

visible_subject: Option<Option<String>>

Issued document visible subject

rc_center: Option<Option<String>>

Issued document revenue center [or cost center if type=supplier_order].

notes: Option<Option<String>>

Issued document extra notes

rivalsa: Option<Option<f64>>

Issued document "Rivalsa INPS" percentual value

cassa: Option<Option<f64>>

Issued document "Cassa previdenziale" percentual value

amount_cassa: Option<Option<f64>>

[Read Only] Issued document cassa amount.

cassa_taxable: Option<Option<f64>>

Issued document cassa taxable percentage

amount_cassa_taxable: Option<Option<f64>>

[Can be set only if cassa_taxable is NULL] Issued document cassa taxable amount

cassa2: Option<Option<f64>>

Issued document "Cassa previdenziale 2" percentual value

amount_cassa2: Option<Option<f64>>

[Read Only] Issued document cassa2 amount

cassa2_taxable: Option<Option<f64>>

Issued document cassa2 taxable percentage

amount_cassa2_taxable: Option<Option<f64>>

[Can be set only if cassa2_taxable is NULL] Issued document cassa2 taxable amount

global_cassa_taxable: Option<Option<f64>>

Issued document global cassa taxable percentage

amount_global_cassa_taxable: Option<Option<f64>>

[Can be set only if global_cassa_taxable is NULL] Issued document global cassa taxable amount

withholding_tax: Option<Option<f64>>

Issued document withholding tax (ritenuta d’acconto) percentual value

withholding_tax_taxable: Option<Option<f64>>

Issued document withholding tax taxable (imponibile) percentual value

other_withholding_tax: Option<Option<f64>>

Issued document other withholding tax (altra ritenuta) percentual value

stamp_duty: Option<Option<f64>>

Issued document stamp duty value [0 if not present]

payment_method: Option<Box<PaymentMethod>>use_split_payment: Option<Option<bool>>

Issued document uses split payment

use_gross_prices: Option<Option<bool>>

Issued document uses gross prices

e_invoice: Option<Option<bool>>

Issued document is an e-invoice.

ei_data: Option<Option<Box<IssuedDocumentEiData>>>ei_cassa_type: Option<Option<String>>

E-invoice cassa type

ei_cassa2_type: Option<Option<String>>

E-invoice cassa2 type

ei_withholding_tax_causal: Option<Option<String>>

E-invoice withholding tax causal

ei_other_withholding_tax_type: Option<Option<String>>

E-invoice other withholding tax type

ei_other_withholding_tax_causal: Option<Option<String>>

E-invoice other withholding tax causal

items_list: Option<Option<Vec<IssuedDocumentItemsListItem>>>payments_list: Option<Option<Vec<IssuedDocumentPaymentsListItem>>>template: Option<Box<DocumentTemplate>>delivery_note_template: Option<Box<DocumentTemplate>>acc_inv_template: Option<Box<DocumentTemplate>>h_margins: Option<Option<i32>>

Issued document PDF horizontal margins

v_margins: Option<Option<i32>>

Issued document PDF vertical margins

show_payments: Option<Option<bool>>

Show the expiration dates of the payments on the document

show_payment_method: Option<Option<bool>>

Show the payment method details on the document

show_totals: Option<ShowTotals>

Show totals mode

show_notification_button: Option<Option<bool>>

Show notification button in the PDF

show_tspay_button: Option<Option<bool>>

Show ts pay button in the PDF

delivery_note: Option<Option<bool>>

Issued document has delivery note

accompanying_invoice: Option<Option<bool>>

Issued document has an accompanying invoice

dn_number: Option<Option<i32>>

Issued document attached delivery note number

dn_date: Option<Option<String>>

Issued document attached delivery note date

dn_ai_packages_number: Option<Option<String>>

Issued document attached delivery note number of packages

dn_ai_weight: Option<Option<String>>

Issued document attached delivery note package weight

dn_ai_causal: Option<Option<String>>

Issued document attached delivery note causal

dn_ai_destination: Option<Option<String>>

Issued document attached delivery note destination

dn_ai_transporter: Option<Option<String>>

Issued document attached delivery note transporter

dn_ai_notes: Option<Option<String>>

Issued document attached delivery note notes

is_marked: Option<Option<bool>>

Issued document is marked

amount_net: Option<Option<f64>>

[Read only] Issued document total net amount

amount_vat: Option<Option<f64>>

[Read Only] Issued document total vat amount

amount_gross: Option<Option<f64>>

[Read Only] Issued document total gross amount

amount_due_discount: Option<Option<f64>>

Issued document amount due discount

amount_rivalsa: Option<Option<f64>>

[Read Only] Issued document rivalsa amount

amount_rivalsa_taxable: Option<Option<f64>>

Issued document taxable rivalsa amount

amount_withholding_tax: Option<Option<f64>>

[Read Only] Issued document withholding tax amount (ritenuta d’acconto).

amount_withholding_tax_taxable: Option<Option<f64>>

Issued document taxable withholding tax amount

amount_other_withholding_tax: Option<Option<f64>>

[Read Only] Issued document other withholding tax amount (altra ritenuta)

amount_other_withholding_tax_taxable: Option<Option<f64>>

Issued document taxable other withholding tax amount

amount_enasarco_taxable: Option<Option<f64>>

Issued document taxable enasarco amount

extra_data: Option<Option<Box<IssuedDocumentExtraData>>>seen_date: Option<Option<String>>

Issued document seen date

next_due_date: Option<Option<String>>

Issued document date of the next not paid payment

url: Option<Option<String>>

[Temporary] [Read Only] Issued document url of the document PDF file

dn_url: Option<Option<String>>

[Temporary] [Read Only] Issued document url of the attached delivery note PDF file

ai_url: Option<Option<String>>

[Temporary] [Read Only] Issued document url of the accompanying invoice PDF file

attachment_url: Option<Option<String>>

[Temporary] [Read Only] Issued document url of the attached file

attachment_token: Option<Option<String>>

[Write Only] Issued document attachment token returned by POST /issued_documents/attachment

ei_raw: Option<Option<Value>>

Issued document advanced raw attributes for e-invoices

ei_status: Option<Option<EiStatus>>

[Read only] Status of the e-invoice. * attempt - We are trying to send the invoice, please wait up to 2 hours * missing - The invoice is missing * not_sent - The invoice has yet to be sent * sent - The invoice was sent * pending - The checks for the digital signature and sending are in progress * processing - The SDI is delivering the invoice to the customer * error - An error occurred while handling the invoice, please try to resend it or contact support * discarded - The invoice has been rejected by the SDI, so it must be corrected and re-sent * not_delivered - The SDI was unable to deliver the invoice * accepted - The customer accepted the invoice * rejected - The customer rejected the invoice, so it must be corrected * no_response - A response has not yet been received whithin the deadline, contact the customer to ascertain the status of the invoice * manual_accepted - The customer accepted the invoice * manual_rejected - The customer rejected the invoice

locked: Option<Option<bool>>

Issued Document can’t be edited

created_at: Option<Option<String>>

Issued document creation date

updated_at: Option<Option<String>>

Issued document last update date

Implementations