IssuedDocumentExtraData

Struct IssuedDocumentExtraData 

pub struct IssuedDocumentExtraData {
    pub show_sofort_button: Option<Option<bool>>,
    pub multifatture_sent: Option<Option<i32>>,
    pub ts_communication: Option<Option<bool>>,
    pub ts_flag_tipo_spesa: Option<Option<f64>>,
    pub ts_pagamento_tracciato: Option<Option<bool>>,
    pub ts_tipo_spesa: Option<Option<String>>,
    pub ts_opposizione: Option<Option<bool>>,
    pub ts_status: Option<Option<i32>>,
    pub ts_file_id: Option<Option<String>>,
    pub ts_sent_date: Option<Option<String>>,
    pub ts_full_amount: Option<Option<bool>>,
    pub imported_by: Option<Option<String>>,
}
IssuedDocumentExtraData : Issued document extra data [TS fields follow the technical specifications provided by "Sistema Tessera Sanitaria"]

Fields

show_sofort_button: Option<Option<bool>>multifatture_sent: Option<Option<i32>>ts_communication: Option<Option<bool>>

Send issued document to "Sistema Tessera Sanitaria"

ts_flag_tipo_spesa: Option<Option<f64>>

Issued document ts "tipo spesa" [TK, FC, FV, SV,SP, AD, AS, ECG, SR]

ts_pagamento_tracciato: Option<Option<bool>>

Issued document ts traced payment

ts_tipo_spesa: Option<Option<String>>

Can be [ ‘TK’, ‘FC’, ‘FV’, ‘SV’, ‘SP’, ‘AD’, ‘AS’, ‘SR’, ‘CT’, ‘PI’, ‘IC’, ‘AA’ ]. Refer to the technical specifications to learn more.

ts_opposizione: Option<Option<bool>>

Issued document ts "opposizione"

ts_status: Option<Option<i32>>

Issued document ts status

ts_file_id: Option<Option<String>>

Issued document ts file id

ts_sent_date: Option<Option<String>>

Issued document ts sent date

ts_full_amount: Option<Option<bool>>

Issued document ts total amount

imported_by: Option<Option<String>>

Issued document imported by software

Implementations

Source

impl IssuedDocumentExtraData

pub fn new() -> IssuedDocumentExtraData

Issued document extra data [TS fields follow the technical specifications provided by "Sistema Tessera Sanitaria"]